/**
 * @author Chenzhyc
 * @description CC视频播放器
 */

 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
 import appendQuery from 'append-query';
 
 const ccPlayerHost = 'https://p.bokecc.com/player';
 const playerType = '1';
 
 function getSWF(swfID) {
   if (window.document[swfID]) {
	 return window.document[swfID];
   } else if (navigator.appName.indexOf("Microsoft") == -1) {
	 if (document.embeds && document.embeds[swfID]) {
	   return document.embeds[swfID];
	 }
   } else {
	 return document.getElementById(swfID);
   }
 }
 class PBUVideoPlayer extends Component {
   constructor(props) {
	 super(props);
	 this.state = {
	   ...props,
	 };
	 this.intervalTimer = null;
	 this.startTime = 0;
	 this.playState = false
   }
 
 
   openTimer() {
	 if (!this.props.onRecordPlaytime) {
	   return
	 }
	 const interval = this.props.interval
	 this.intervalTimer = setInterval(() => {
	   this.startTime = Date.now()
	   this.props.onRecordPlaytime(interval)
	 }, interval * 1000)
   }
 
   // 计算本次播放暂时的时长
   getDuration() {
	 if (!this.props.onRecordPlaytime) {
	   return
	 }
	 clearInterval(this.intervalTimer)
	 const currentTime = Date.now()
	 const duration = Math.ceil((currentTime - this.startTime) / 1000)
	 this.startTime = currentTime
	 this.props.onRecordPlaytime(duration)
   }
 
   loadScript() {
	 //先删掉之前的视频播放器节点
	 if (this.refs[`domRef_${this.state.vid}`].hasChildNodes()) {
	   this.refs[`domRef_${this.state.vid}`].removeChild(this.refs[`domRef_${this.state.vid}`].childNodes[0]);
	 }
	 window.clearInterval(this.intervalTime);
 
	 const videoSrc = appendQuery(ccPlayerHost, {
	   vid: this.state.vid,
	   siteid: this.state.siteId,
	   autoStart: this.state.autoStart,
	   width: this.state.width,
	   height: this.state.height,
	   playerid: this.state.playerid,
	   playertype: playerType
	 });
 
	 const oScript = document.createElement('script');
	 oScript.type = 'text/javascript';
	 oScript.async = true;
	 oScript.src = videoSrc;
	 this.refs[`domRef_${this.state.vid}`].appendChild(oScript);
   }
 
   componentDidMount() {
	 window.on_CCH5player_ready = (obj) => {
	   console.log('CCH5player_ready', obj);
	 }
 
	 window.on_CCH5player_play = () => {
	   this.openTimer()
	   this.startTime = Date.now()
	   this.playState = true
	   console.log('CCH5player_play');
	 }
 
	 window.on_CCH5player_pause = () => {
	   this.getDuration()
	   this.playState = false
	   console.log('CCH5player_pause');
	 }
 
	 window.on_CCH5player_ended = () => {
	   this.getDuration()
	   this.playState = false
	   console.log('CCH5player_ended');
	 }
	 this.loadScript();
	 window.get_cc_verification_code = (vid) => {
	   return this.props.onGetVerificationCode(vid);
	 }
 
	 window.on_spark_player_start = () => {
	   this.openTimer()
	   this.startTime = Date.now()
	   this.playState = true
	   console.log('on_spark_player_start');
	 }
 
	 window.on_spark_player_pause = () => {
	   this.getDuration()
	   this.playState = false
	   console.log('on_spark_player_pause');
	 }
 
	 window.on_spark_player_resume = () => {
	   this.openTimer()
	   this.startTime = Date.now()
	   this.playState = true
	   console.log('on_spark_player_resume');
	 }
 
	 window.on_spark_player_stop = () => {
	   this.getDuration()
	   this.playState = false
	   console.log('on_spark_player_stop');
	 }
 
	 window.on_spark_player_ready = () => {
	   console.log('on_spark_player_ready');
	 }
 
	 window.on_player_seek = () => {
	   console.log('on_player_seek');
	 }
 
	 window.on_cc_player_init = (vid, objectId) => {
	   this.player = getSWF(objectId);
	   const config = {
		 on_player_stop: "on_spark_player_stop",
		 on_player_pause: "on_spark_player_pause",
		 on_player_resume: "on_spark_player_resume",
		 on_player_ready: "on_spark_player_ready",
		 on_player_start: "on_spark_player_start",
		 on_player_seek: "on_spark_player_seek"
	   }
 
	   this.player.setConfig(config);
	 }
   }
 
   componentWillReceiveProps(nextProps) {
	 this.setState({
	   ...nextProps
	 });
   }
 
   shouldComponentUpdate(nextProps, nextState) {
	 return nextProps.vid !== this.props.vid;
   }
 
   componentDidUpdate() {
	 this.startTime = 0;
	 this.loadScript();
   }
 
   componentWillUnmount() {
	 if (this.playState) {
	   this.getDuration()
	 }
	 clearInterval(this.intervalTimer);
   }
 
   render() {
	 return (
	   <div ref={`domRef_${this.state.vid}`}>
 
	   </div>
	 )
   }
 }
 
 PBUVideoPlayer.propTypes = {
   /**
	* siteId
	*/
   siteId: PropTypes.string.isRequired,
 
   /**
	* 视频唯一标识符
	*/
   vid: PropTypes.string.isRequired,
   /**
	* 播放器宽度
	*/
   width: PropTypes.number,
   /**
	* 播放器高度
	*/
   height: PropTypes.number,
   /**
	* 是否自动播放，默认false
	*/
   autoStart: PropTypes.bool,
   /**
	* 播放器id，
	*/
   playerid: PropTypes.string,
   /**
	* @param currentPosition  已播放的秒数
	*/
   onRecordPlaytime: PropTypes.func,
   /**
	* 获取用于鉴权的验证码
	* @param {string} vid 视频id
	* @return {string}
	*/
   onGetVerificationCode: PropTypes.func,
   /**
	  * 定时回调播放时长
	  * @param {number}  间隔时间
	  */
   interval: PropTypes.number,
 }
 
 PBUVideoPlayer.defaultProps = {
   vid: '',
   siteId: '',
   width: 600,
   height: 490,
   autoStart: false,
   playerid: '',
   interval: 60,
   onGetVerificationCode: (vid) => {
	 console.log('vid = ', vid);
	 return vid;
   },
 }
 
 
 export default PBUVideoPlayer;
 